@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Maven::LocalRepository;
-$Maven::LocalRepository::VERSION = '1.13';
+$Maven::LocalRepository::VERSION = '1.14';
 # ABSTRACT: An local repository from which to resolve artifacts
 # PODNAME: Maven::LocalRepository
 
@@ -65,7 +65,7 @@ sub _init {
             $^O =~ /^cygwin$/i
 
                 #? Cygwin::win_to_posix_path($local_repository_path)
-            ? `cygpath -u $local_repository_path`
+            ? `cygpath -u '$local_repository_path'`
             : $local_repository_path
         )->as_string()
     );
@@ -135,7 +135,7 @@ Maven::LocalRepository - An local repository from which to resolve artifacts
 
 =head1 VERSION
 
-version 1.13
+version 1.14
 
 =head1 AUTHOR
 
